@@ -56,36 +56,43 @@ typedef enum {
  * Flags used when creating the blob.
  **/
 typedef enum {
-	JCAT_BLOB_FLAG_NONE		= 0,
-	JCAT_BLOB_FLAG_IS_UTF8		= 1 << 0,
+	JCAT_BLOB_FLAG_NONE = 0,
+	JCAT_BLOB_FLAG_IS_UTF8 = 1 << 0,
 	/*< private >*/
 	JCAT_BLOB_FLAG_LAST
 } JcatBlobFlags;
 
-struct _JcatBlobClass
-{
-	GObjectClass		 parent_class;
-	gpointer		 padding[15];
+struct _JcatBlobClass {
+	GObjectClass parent_class;
+	gpointer padding[15];
 };
 
-JcatBlobKind	 jcat_blob_kind_from_string		(const gchar	*kind);
-const gchar	*jcat_blob_kind_to_string		(JcatBlobKind	 kind);
-const gchar	*jcat_blob_kind_to_filename_ext		(JcatBlobKind	 kind);
+JcatBlobKind
+jcat_blob_kind_from_string(const gchar *kind);
+const gchar *
+jcat_blob_kind_to_string(JcatBlobKind kind);
+const gchar *
+jcat_blob_kind_to_filename_ext(JcatBlobKind kind);
 
-JcatBlob	*jcat_blob_new				(JcatBlobKind	 kind,
-							 GBytes		*data);
-JcatBlob	*jcat_blob_new_full			(JcatBlobKind	 kind,
-							 GBytes		*data,
-							 JcatBlobFlags	 flags);
-JcatBlob	*jcat_blob_new_utf8			(JcatBlobKind	 kind,
-							 const gchar	*data);
-gchar		*jcat_blob_to_string 			(JcatBlob	*self);
-GBytes		*jcat_blob_get_data			(JcatBlob	*self);
-gchar		*jcat_blob_get_data_as_string		(JcatBlob	*self);
-JcatBlobKind	 jcat_blob_get_kind			(JcatBlob	*self);
-gint64		 jcat_blob_get_timestamp		(JcatBlob	*self);
-void		 jcat_blob_set_timestamp		(JcatBlob	*self,
-							 gint64		 timestamp);
-const gchar	*jcat_blob_get_appstream_id		(JcatBlob	*self);
-void		 jcat_blob_set_appstream_id		(JcatBlob	*self,
-							 const gchar	*appstream_id);
+JcatBlob *
+jcat_blob_new(JcatBlobKind kind, GBytes *data);
+JcatBlob *
+jcat_blob_new_full(JcatBlobKind kind, GBytes *data, JcatBlobFlags flags);
+JcatBlob *
+jcat_blob_new_utf8(JcatBlobKind kind, const gchar *data);
+gchar *
+jcat_blob_to_string(JcatBlob *self);
+GBytes *
+jcat_blob_get_data(JcatBlob *self);
+gchar *
+jcat_blob_get_data_as_string(JcatBlob *self);
+JcatBlobKind
+jcat_blob_get_kind(JcatBlob *self);
+gint64
+jcat_blob_get_timestamp(JcatBlob *self);
+void
+jcat_blob_set_timestamp(JcatBlob *self, gint64 timestamp);
+const gchar *
+jcat_blob_get_appstream_id(JcatBlob *self);
+void
+jcat_blob_set_appstream_id(JcatBlob *self, const gchar *appstream_id);
